@@ -565,6 +565,12 @@ NTip.multiPhylo <- function (phy) {
   vapply(phy, NTip.phylo, integer(1))
 }
 
+#' @rdname NTip
+#' @export
+NTip.phyDat <- function (phy) {
+  length(phy)
+}
+
 #' @rdname NTip
 #' @export
 NTip.matrix <- function (phy) {
