@@ -13,4 +13,9 @@ test_that("Cladistic info calculated correctly", {
   expect_equal(NUnrooted(4) * NUnrooted(5),
                TreesMatchingTree(tr1))
   expect_equal(Log2Unrooted(8) - log2(45), CladisticInfo(tr1))
+
+  sizes <- 2:7
+  expect_equal(setNames(-log2(apply(cbind(2:7, 7:2), 1, TreesMatchingSplit) /
+                                NUnrooted(9)), 12:17),
+               CladisticInfo(as.Splits(PectinateTree(9))))
 })
